<?php
/**
 * Maximum Products per User for WooCommerce - Formula Section Settings
 *
 * @version 2.3.0
 * @since   2.3.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_MPPU_Settings_Formula' ) ) :

class Alg_WC_MPPU_Settings_Formula extends Alg_WC_MPPU_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 2.3.0
	 * @since   2.3.0
	 */
	function __construct() {
		$this->id   = 'formula';
		$this->desc = __( 'Formula', 'maximum-products-per-user-for-woocommerce' );
		parent::__construct();
	}

	/**
	 * get_settings.
	 *
	 * @version 2.3.0
	 * @since   2.3.0
	 * @todo    [dev] add link to site ("Check plugin site for more examples")
	 */
	function get_settings() {
		return array(
			array(
				'title'    => __( 'Max Quantity by Formula', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => __( 'This section introduces an alternative method for setting max quantities.', 'maximum-products-per-user-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_mppu_formula_options',
			),
			array(
				'title'    => __( 'Max quantity by formula', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => '<strong>' . __( 'Enable', 'maximum-products-per-user-for-woocommerce' ) . '</strong>',
				'desc_tip' => apply_filters( 'alg_wc_mppu_settings', sprintf( 'You will need %s plugin to enable "max quantity by formula" option.',
					'<a target="_blank" href="https://wpfactory.com/item/maximum-products-per-user-for-woocommerce/">' . 'Maximum Products per User for WooCommerce Pro' . '</a>' ) ),
				'id'       => 'alg_wc_mppu_formula_enabled',
				'default'  => 'no',
				'type'     => 'checkbox',
				'custom_attributes' => apply_filters( 'alg_wc_mppu_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'title'    => __( 'Formula', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => __( 'One shortcode per line.', 'maximum-products-per-user-for-woocommerce' ),
				'id'       => 'alg_wc_mppu_formula',
				'default'  => '',
				'type'     => 'textarea',
				'css'      => 'width:100%;min-height:200px;',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_mppu_formula_options',
			),
			array(
				'title'    => __( 'Notes', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => '<ul>' . '<li>' . implode ( '</li><li>', array(
					'* ' . sprintf( __( 'You need to use %s shortcode here.', 'maximum-products-per-user-for-woocommerce' ),
						'<code>[alg_wc_mppu_max_qty]</code>' ),
					'* ' . __( 'One shortcode per line.', 'maximum-products-per-user-for-woocommerce' ),
					'* ' . __( 'Algorithm stops when first matching shortcode is found (from top to bottom).', 'maximum-products-per-user-for-woocommerce' ),
					'* ' . sprintf( __( 'Available shortcode attributes: %s.', 'maximum-products-per-user-for-woocommerce' ),
						'<code>' . implode( '</code>, <code>', array( 'user_id', 'user_role', 'product_id', 'term_id', 'max_qty' ) ) . '</code>' ),
					'* ' . sprintf( __( '%s attribute and at least one other attribute are required.', 'maximum-products-per-user-for-woocommerce' ),
						'<code>max_qty</code>' ),
					'* ' . sprintf( __( 'You need to enable %s checkbox in "Quantities" section to use %s attribute.', 'maximum-products-per-user-for-woocommerce' ),
						__( '"Per Product"', 'maximum-products-per-user-for-woocommerce' ), '<code>product_id</code>' ),
					'* ' . sprintf( __( 'You need to enable %s checkbox in "Quantities" section to use %s attribute.', 'maximum-products-per-user-for-woocommerce' ),
						__( '"Per product category" and/or "Per product tag"', 'maximum-products-per-user-for-woocommerce' ), '<code>term_id</code>' ),
					'* ' . sprintf( __( 'You can not use %s and %s simultaneously in one shortcode.', 'maximum-products-per-user-for-woocommerce' ),
						'<code>product_id</code>', '<code>term_id</code>' ),
				) ) . '</li>' . '</ul>',
				'type'     => 'title',
				'id'       => 'alg_wc_mppu_formula_notes_options',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_mppu_formula_notes_options',
			),
			array(
				'title'    => __( 'Examples', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => '<ul>' . '<li>' . implode( '</li><li>', array(
					'* ' . '<code>[alg_wc_mppu_max_qty max_qty="18" user_id="2,5"]</code>' . ' - ' .
						'<em>' . sprintf( __( 'Sets maximum quantity to %s for users %s and %s.', 'maximum-products-per-user-for-woocommerce' ),
							'<code>18</code>', '<code>2</code>', '<code>5</code>' ) . '</em>',
					'* ' . '<code>[alg_wc_mppu_max_qty max_qty="18" user_id="2,5" product_id="100,110"]</code>' . ' - ' .
						'<em>' . sprintf( __( 'Sets maximum quantity to %s for products %s and %s for users %s and %s.', 'maximum-products-per-user-for-woocommerce' ),
							'<code>18</code>', '<code>100</code>', '<code>110</code>', '<code>2</code>', '<code>5</code>' ) . '</em>',
				) ). '</li>' . '</ul>',
				'type'     => 'title',
				'id'       => 'alg_wc_mppu_formula_examples_options',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_mppu_formula_examples_options',
			),
		);
	}

}

endif;

return new Alg_WC_MPPU_Settings_Formula();
