<?php
/**
 * Maximum Products per User for WooCommerce - Frontend Section Settings
 *
 * @version 2.4.0
 * @since   2.4.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_MPPU_Settings_Frontend' ) ) :

class Alg_WC_MPPU_Settings_Frontend extends Alg_WC_MPPU_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 2.4.0
	 * @since   2.4.0
	 */
	function __construct() {
		$this->id   = 'frontend';
		$this->desc = __( 'Frontend', 'maximum-products-per-user-for-woocommerce' );
		parent::__construct();
	}

	/**
	 * get_placeholders_desc.
	 *
	 * @version 2.0.0
	 * @since   1.0.0
	 */
	function get_placeholders_desc( $values ) {
		return sprintf( __( 'Placeholders: %s.', 'maximum-products-per-user-for-woocommerce' ), '<code>' . implode( '</code>, <code>', $values ) . '</code>' );
	}

	/**
	 * get_settings.
	 *
	 * @version 2.4.0
	 * @since   2.4.0
	 */
	function get_settings() {

		$frontend_settings = array(
			array(
				'title'    => __( 'Frontend Options', 'maximum-products-per-user-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_mppu_frontend_options',
			),
			array(
				'title'    => __( 'Validate on add to cart', 'maximum-products-per-user-for-woocommerce' ),
				'desc_tip' => __( 'Validate quantities immediately when "add to cart" button is pressed.', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => __( 'Validate', 'maximum-products-per-user-for-woocommerce' ),
				'id'       => 'alg_wc_mppu_validate_on_add_to_cart',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Customer message', 'maximum-products-per-user-for-woocommerce' ),
				'desc_tip' => __( 'You can use HTML and/or shortcode here.', 'maximum-products-per-user-for-woocommerce' ) . ' ' .
					sprintf( __( 'E.g.: %s.', 'maximum-products-per-user-for-woocommerce' ), '<em>[alg_wc_mppu_translate]</em>' ),
				'desc'     => $this->get_placeholders_desc( array( '%max_qty%', '%product_title%', '%qty_already_bought%', '%remaining_qty%' ) ),
				'id'       => 'wpjup_wc_maximum_products_per_user_message',
				'default'  => __( 'You can only buy maximum %max_qty% pcs. of %product_title% (you already bought %qty_already_bought% pcs.).', 'maximum-products-per-user-for-woocommerce' ),
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_mppu_raw' => true,
			),
			array(
				'title'    => __( 'Block checkout page', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => __( 'Block', 'maximum-products-per-user-for-woocommerce' ),
				'desc_tip' => __( 'This will stop customer from accessing the checkout page on exceeded quantities. Customer will be redirected to the cart page.', 'maximum-products-per-user-for-woocommerce' ),
				'id'       => 'wpjup_wc_maximum_products_per_user_stop_from_seeing_checkout',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_mppu_frontend_options',
			),
		);

		return $frontend_settings;
	}

}

endif;

return new Alg_WC_MPPU_Settings_Frontend();
