<?php
/**
 * Maximum Products per User for WooCommerce - General Section Settings
 *
 * @version 2.4.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_MPPU_Settings_General' ) ) :

class Alg_WC_MPPU_Settings_General extends Alg_WC_MPPU_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id   = '';
		$this->desc = __( 'General', 'maximum-products-per-user-for-woocommerce' );
		parent::__construct();
	}

	/**
	 * get_settings.
	 *
	 * @version 2.4.0
	 * @since   1.0.0
	 * @todo    [dev] add custom date range *unit* option (i.e. "seconds", "minutes", "hours" etc.)
	 * @todo    [dev] (maybe) exclude unnecessary statuses from `alg_wc_mppu_order_status` (e.g. "Cancelled", "Refunded", "Failed")
	 */
	function get_settings() {

		$plugin_settings = array(
			array(
				'title'    => __( 'Maximum Products per User Options', 'maximum-products-per-user-for-woocommerce' ),
				'type'     => 'title',
				'desc'     => '<p>' . '* ' . __( 'Please note that there is no maximum quantity set for <strong>guest</strong> (i.e. not-logged) users.', 'maximum-products-per-user-for-woocommerce' ) . ' ' .
					sprintf( __( 'Possible solution would be to disable guest checkout via %s option in %s.', 'maximum-products-per-user-for-woocommerce' ),
						'<em>"' . __( 'Allow customers to place orders without an account', 'woocommerce' ) . '"</em>',
						'<a href="' . admin_url( 'admin.php?page=wc-settings&tab=account' ) . '">' .
							__( 'WooCommerce > Settings > Accounts & Privacy > Guest checkout', 'maximum-products-per-user-for-woocommerce' ) . '</a>'
					) . '</p>' .
					'<p>' . '* ' . sprintf( __( 'While data is recalculated automatically (but only after the plugin was enabled), you can also force manual recalculation by running %s tool.', 'maximum-products-per-user-for-woocommerce' ),
						'<a href="' . admin_url( 'admin.php?page=wc-settings&tab=alg_wc_mppu&section=tools' ) . '">' .
							__( 'Recalculate sales data', 'maximum-products-per-user-for-woocommerce' ) . '</a>' ) . ' ' .
						__( 'This is useful on initial plugin install (i.e. to calculate sales data from before the plugin was enabled).', 'maximum-products-per-user-for-woocommerce' ) .
					'</p>',
				'id'       => 'alg_wc_mppu_plugin_options',
			),
			array(
				'title'    => __( 'Maximum Products per User', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => '<strong>' . __( 'Enable plugin', 'maximum-products-per-user-for-woocommerce' ) . '</strong>',
				'desc_tip' => __( 'Limit number of items your WooCommerce customers can buy (lifetime or in selected date range).', 'maximum-products-per-user-for-woocommerce' ),
				'id'       => 'wpjup_wc_maximum_products_per_user_plugin_enabled',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_mppu_plugin_options',
			),
		);

		$general_settings = array(
			array(
				'title'    => __( 'General Options', 'maximum-products-per-user-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_mppu_general_options',
			),
			array(
				'title'    => __( 'Date range', 'maximum-products-per-user-for-woocommerce' ),
				'id'       => 'alg_wc_mppu_date_range',
				'default'  => 'lifetime',
				'type'     => 'select',
				'class'    => 'chosen_select',
				'options'  => array(
					'lifetime'      => __( 'Lifetime', 'maximum-products-per-user-for-woocommerce' ),
					'this_hour'     => __( 'This hour', 'maximum-products-per-user-for-woocommerce' ),
					'this_day'      => __( 'This day', 'maximum-products-per-user-for-woocommerce' ),
					'this_week'     => __( 'This week', 'maximum-products-per-user-for-woocommerce' ),
					'this_month'    => __( 'This month', 'maximum-products-per-user-for-woocommerce' ),
					'this_year'     => __( 'This year', 'maximum-products-per-user-for-woocommerce' ),
					'last_hour'     => __( 'Last hour', 'maximum-products-per-user-for-woocommerce' ),
					'last_24_hours' => __( 'Last 24 hours', 'maximum-products-per-user-for-woocommerce' ),
					'last_7_days'   => __( 'Last 7 days', 'maximum-products-per-user-for-woocommerce' ),
					'last_30_days'  => __( 'Last 30 days', 'maximum-products-per-user-for-woocommerce' ),
					'last_365_days' => __( 'Last 365 days', 'maximum-products-per-user-for-woocommerce' ),
					'custom'        => __( 'Custom', 'maximum-products-per-user-for-woocommerce' ),
				),
			),
			array(
				'desc'     => __( 'Custom date range (in seconds)', 'maximum-products-per-user-for-woocommerce' ),
				'desc_tip' => __( 'Used when "Custom" option is selected in "Date range".', 'maximum-products-per-user-for-woocommerce' ),
				'id'       => 'alg_wc_mppu_date_range_custom',
				'default'  => 1,
				'type'     => 'number',
				'custom_attributes' => array( 'min' => 1 ),
			),
			array(
				'title'    => __( 'Order statuses', 'maximum-products-per-user-for-woocommerce' ),
				'desc_tip' => __( 'Choose order statuses when product quantities should be updated.', 'maximum-products-per-user-for-woocommerce' ) . ' ' .
					__( 'If you select multiple order statuses, quantities are updated only once, on whichever status change occurs first.', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => sprintf( __( 'You will need to %s after changing "Order statuses" option.', 'maximum-products-per-user-for-woocommerce' ),
					'<a href="' . admin_url( 'admin.php?page=wc-settings&tab=alg_wc_mppu&section=tools' ) . '">' .
						__( 'Recalculate sales data', 'maximum-products-per-user-for-woocommerce' ) . '</a>' ),
				'id'       => 'alg_wc_mppu_order_status',
				'default'  => array( 'wc-completed' ),
				'type'     => 'multiselect',
				'class'    => 'chosen_select',
				'options'  => wc_get_order_statuses(),
			),
			array(
				'title'    => __( 'Use variations', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => __( 'Enable', 'maximum-products-per-user-for-woocommerce' ),
				'desc_tip' => __( 'Use variations in "All products" and "Per product" calculations.', 'maximum-products-per-user-for-woocommerce' ),
				'id'       => 'alg_wc_mppu_use_variations',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'User roles', 'maximum-products-per-user-for-woocommerce' ),
				'desc_tip' => __( 'Set different maximum product quantities for different user roles.', 'maximum-products-per-user-for-woocommerce' ),
				'desc'     => __( 'Enable', 'maximum-products-per-user-for-woocommerce' ),
				'id'       => 'alg_wc_mppu_use_user_roles',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_mppu_general_options',
			),
		);

		return array_merge( $plugin_settings, $general_settings );
	}

}

endif;

return new Alg_WC_MPPU_Settings_General();
